background library
Classes
- Background
- A widget that displays a background which can be either an image or a video. The background is determined based on the file extension of the provided path. It also overlays a child widget on top of the background.